﻿using Android.App;
using Android.Graphics;
using Android.OS;
using System;
using System.IO;
using ThinkGeo.MapSuite.AndroidEdition;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.Portable;

namespace SingTileRefreshTest
{
    [Activity(MainLauncher = true, Label = "ArpentGIS", ConfigurationChanges = Android.Content.PM.ConfigChanges.Orientation | Android.Content.PM.ConfigChanges.ScreenSize)]
    public class MainActivity : Activity
    {
        private MapView mapView;
        private LayerOverlay layerOverlay;
        private InMemoryFeatureLayer vehicleLayer;

        static MainActivity()
        {
            Pcl.Current = new AndroidEditionPclShareEnviroment();
        }

        protected override void OnCreate(Bundle bundle)
        {
            base.OnCreate(bundle);
            SetContentView(Resource.Layout.Main);

            mapView = FindViewById<MapView>(Resource.Id.androidMap);
            mapView.MapUnit = GeographyUnit.Meter;
            mapView.ZoomLevelSet = new GoogleMapsZoomLevelSet();

            foreach (MapTool m in mapView.MapTools)
              m.IsEnabled = false;

            OpenStreetMapTileOverlay osmTileOverlay = new OpenStreetMapTileOverlay();
            mapView.Overlays.Add(osmTileOverlay);

            mapView.CurrentExtent = osmTileOverlay.GetBoundingBox();


          //  LayerOverlay bkgOverlay = new LayerOverlay();
          //  bkgOverlay.TileType = TileType.SingleTile;
          //  mapView.Overlays.Add(bkgOverlay);

            InMemoryFeatureLayer m_GpsCurrentPos = new InMemoryFeatureLayer();
       //     m_GpsCurrentPos.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = new PointStyle(GetGeoImageFromImageId(Resource.Drawable.Micheal_vehicle));
       //     m_GpsCurrentPos.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
          //  m_GpsCurrentPos.IsVisible = false;

            LayerOverlay gpsOverlay = new LayerOverlay();
            gpsOverlay.Layers.Add(m_GpsCurrentPos);
            gpsOverlay.TileType = TileType.SingleTile;
            mapView.Overlays.Add(gpsOverlay);

       /*     layerOverlay = new LayerOverlay();
            layerOverlay.TileType = TileType.SingleTile;

            vehicleLayer = new InMemoryFeatureLayer();
            vehicleLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = new PointStyle(GetGeoImageFromImageId(Resource.Drawable.Micheal_vehicle));
            vehicleLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            layerOverlay.Layers.Add(vehicleLayer);
            mapView.Overlays.Add(layerOverlay);

            System.Timers.Timer timer = new System.Timers.Timer();
            timer.Interval = 1000;
            timer.Elapsed += timer_Elapsed;
           // timer.Start();*/
        }

        private void timer_Elapsed(object sender, System.Timers.ElapsedEventArgs e)
        {
          mapView.Post(() =>
                       {
                         lock (vehicleLayer)
                         {
                           vehicleLayer.InternalFeatures.Clear();
                           vehicleLayer.InternalFeatures.Add(new Feature(GetRandomPointShape()));
                           layerOverlay.Refresh();
                         }
                       });
        }

        private PointShape GetRandomPointShape()
        {
            Random raX = new Random();
            double scaleX = raX.NextDouble();

            Random raY = new Random((int)(scaleX * 100));
            double scaleY = raY.NextDouble();

            double valuex = mapView.CurrentExtent.LowerRightPoint.X - mapView.CurrentExtent.UpperLeftPoint.X;
            double valueY = mapView.CurrentExtent.LowerRightPoint.Y - mapView.CurrentExtent.UpperLeftPoint.Y;

            return new PointShape(mapView.CurrentExtent.UpperLeftPoint.X + valuex * scaleX, mapView.CurrentExtent.UpperLeftPoint.Y + valueY * scaleY);
        }

        private GeoImage GetGeoImageFromImageId(int imageId)
        {
            MemoryStream ms = new MemoryStream();
            BitmapFactory.DecodeResource(this.Resources, imageId).Compress(Bitmap.CompressFormat.Png, 100, ms);

            return new GeoImage(ms);
        }
    }
}

